@@ -1,5 +1,5 @@
 from .universe import Mundus
-from .actor import Actor
+from .actor import Actor, event
 from .resource import Resource
 from .producer import Producer
 
