@@ -18,12 +18,14 @@ class Universe:
         return cls.instance
 
     def __init__(self, accuracy:int=3) -> None:
+        """The universe in which the simulation takes place. Should not be instantiated directly."""
         self._id = uuid4().int
         self._timeline = Timeline()
         self._till = int()
         self._accuracy = accuracy
 
     def simulate(self, till: Union[int, float] = inf) -> None:
+        """Simulate the universe to a given time."""
         self._till = till
         while self.timeline.now <= self.till:
             self.timeline.forward(self.till)
@@ -32,18 +34,22 @@ class Universe:
 
     @property
     def timeline(self) -> Timeline:
+        """The timeline of the universe."""
         return self._timeline
 
     @property
     def till(self) -> Union[int, float]:
+        """The time to which the universe is simulated."""
         return self._till
 
     @property
     def now(self) -> Union[int, float]:
+        """The current time of the universe."""
         return self.timeline.now
     
     @property
     def accuracy(self) -> int:
+        """The accuracy of the universe in term of minimum time step. e.g., 3 means 0.001s."""
         return self._accuracy
 
     @accuracy.setter
